@@ -888,7 +888,9 @@ test_item_changed (Test *test,
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add ("/secret-signals/collection-created", Test, NULL,
