@@ -25,6 +25,8 @@
 
 #include "gkm-attributes.h"
 #include "gkm-credential.h"
+#define DEBUG_FLAG GKM_DEBUG_OBJECT
+#include "gkm-debug.h"
 #include "gkm-factory.h"
 #include "gkm-private-xsa-key.h"
 #include "gkm-session.h"
@@ -238,6 +240,7 @@ gkm_private_xsa_key_real_get_attribute (GkmObject *base, GkmSession *session, CK
 		return gkm_attribute_set_bool (attr, FALSE);
 
 	case CKA_UNWRAP_TEMPLATE:
+		gkm_debug ("CKR_ATTRIBUTE_TYPE_INVALID: no CKA_UNWRAP_TEMPLATE on key");
 		return CKR_ATTRIBUTE_TYPE_INVALID;
 
 	case CKA_ALWAYS_AUTHENTICATE:
