@@ -459,7 +459,9 @@ null_log_handler (const gchar *log_domain,
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	egg_libgcrypt_initialize ();
