@@ -214,7 +214,9 @@ test_read_with_schema (Test *test,
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add ("/secret-store/search/read", Test, NULL, setup, test_read, teardown);
